<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
   You may use, distribute and modify this code under the
   terms of the BSD license. See file LICENSE.txt in the
   top-most parent folder distributed with this source code.
   If missing, please write to: johnv@div1sys.com.
*/
?>
<pre>
<?php
//------------------------------------------------------------
// Create DB connection
define( 'USER', 'your-user-id');
define( 'PSWD', 'your-pswd');
$conn_opts = array (
    'i5_naming' => DB2_I5_NAMING_ON,
    'i5_libl' => "JVALANCE QGPL"
);
$conn = db2_connect ("*LOCAL", USER, PSWD, $conn_opts )
    or die("Connection failed! ". db2_conn_errormsg());

//------------------------------------------------------------
// Set up data structure (i.e. arrays) for person rows to insert
$bob = array(
        'firstName' => 'Bob',
        'lastName' => 'Smith',
        'dateOfBirth' => '1975-08-13'
        );
$tom = array(
        'firstName' => 'Tom',
        'lastName' => 'Jones',
        'dateOfBirth' => '1969-11-02'
        );

echo "<h3>Before INSERTs:</h3>";
print_r($bob);
print_r($tom);

//------------------------------------------------------------
// Start with empty table
db2_exec($conn, "delete from person");

//------------------------------------------------------------
// Insert rows in person table
$insert_sql = "insert into person (firstName, lastName, dateOfBirth) values (?, ?, ?)";
$insert_stmt = db2_prepare($conn, $insert_sql)
        or die("<br>Prepare INSERT failed! ". db2_stmt_errormsg());

db2_execute($insert_stmt, $bob);  // create table row for Bob
$bobID = db2_last_insert_id($conn);
$bob['id'] = $bobID;  // save bob's id

db2_execute($insert_stmt, $tom);  // create table row for Tom
$tomID = db2_last_insert_id($conn);
$tom['id'] = $tomID;  // save tom's id

echo "<h3>After INSERTs:</h3>";
print_r($bob);
print_r($tom);


//------------------------------------------------------------
// Update rows in person table
$update_sql = "update person set firstName = ?, lastName = ?, dateOfBirth = ? where id = ?";
$update_stmt = db2_prepare($conn, $update_sql)
        or die("<br>Prepare UPDATE failed! ". db2_stmt_errormsg());

$tom['firstName'] = 'Thomas';
db2_execute($update_stmt, $tom);

$bob['firstName'] = 'Robert';
db2_execute($update_stmt, $bob);

echo "<h3>After UPDATEs:</h3>";
print_r($bob);
print_r($tom);

//------------------------------------------------------------
// Retrieve all rows in person table
$select_all_sql = "select * from person";
$select_all_stmt = db2_prepare($conn, $select_all_sql)
    or die("<br>Select ALL prepare failed! ". db2_stmt_errormsg());
db2_execute($select_all_stmt);

$all_rows = array();
while ($row = db2_fetch_assoc($select_all_stmt )) {
    $all_rows[] = $row;
}

echo "<h3>Select ALL rows:</h3>";
print_r($all_rows);


//------------------------------------------------------------
// Retrieve specific row from person table
$select_row_sql = "select * from person where id = ?";
$select_row_stmt = db2_prepare($conn, $select_row_sql)
    or die("<br>Select ROW prepare failed! ". db2_stmt_errormsg());
db2_execute($select_row_stmt, array($bob['id']));

$row = db2_fetch_assoc($select_row_stmt);

echo "<h3>Select ONE row:</h3>";
print_r($row);


//------------------------------------------------------------
// Calculate Bob's age

$bobsName = getFullName($bob);
$bobsBDayFmtd = formatBirthDate($bob['dateOfBirth']);
$bobsAge = calculateAge($bob['dateOfBirth']);
echo "<h3>Calculate Age:</h3>";
echo "$bobsName was born on $bobsBDayFmtd, and his age is $bobsAge";

//------------------------------------------------------------
// Delete specific row from person table
$delete_row_sql = "delete from person where id = ?";
$delete_row_stmt = db2_prepare($conn, $delete_row_sql)
    or die("<br>Delete row prepare failed! ". db2_stmt_errormsg());
db2_execute($delete_row_stmt, array($tom['id']));
unset($tom);

echo "<h3>After DELETE:</h3>";
print_r($tom);

//------------------
db2_close($conn);


echo "<h3>END OF SCRIPT!!</h3><p />";
/**
 * ==========================================================
 * LOCAL FUNCTIONS
 */

function getFullName( $pers ) {
    return trim($pers['firstName']) . ' ' . trim($pers['lastName']);
}

function formatBirthDate( $dateStr ) {
    return date('D M d, Y', strtotime($dateStr));
}

function calculateAge( $dateStr ) {
    $datetime1 = new DateTime(date('Ymd'));
    $datetime2 = new DateTime($dateStr);
    $interval = $datetime2->diff($datetime1);
    return $interval->format('%r%y years, %m months, %d days');
}
?>
</pre>
