<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
   You may use, distribute and modify this code under the
   terms of the BSD license. See file LICENSE.txt in the
   top-most parent folder distributed with this source code.
   If missing, please write to: johnv@div1sys.com.
*/

require_once('../03-singleton/DB2Connection.php');

class Person_TDG {

    public function __construct( )
    {
    }

    public function delete_all( ) {
        $conn = DB2Connection::getInstance();

        if (!db2_exec($conn, "delete from person"))
            throw new Exception("db2_exec() failed! : ". db2_stmt_errormsg());
    }

    public function insert( $data ) {
        $conn = DB2Connection::getInstance();

        $insert_sql =
        "insert into person (firstName, lastName, dateOfBirth) values (?, ?, ?)";
        $bindVals = array($data['firstName'], $data['lastName'], $data['dateOfBirth'] );

        $insert_stmt = db2_prepare($conn, $insert_sql);
        if (!$insert_stmt) throw new Exception("Prepare INSERT failed! ". db2_stmt_errormsg());

        if (!db2_execute($insert_stmt, $bindVals))
            throw new Exception("db2_execute() failed! : ". db2_stmt_errormsg());
        $id = db2_last_insert_id($conn);
        return $id;
    }

    public function update( $data ) {
        $conn = DB2Connection::getInstance();

        $update_sql =
        "update person set firstName = ?, lastName = ?, dateOfBirth = ? where id = ?";
        $bindVals = array($data['firstName'], $data['lastName'], $data['dateOfBirth'], $data['id'] );

        $update_stmt = db2_prepare($conn, $update_sql);
        if (!$update_stmt) throw new Exception("Prepare UPDATE failed! ". db2_stmt_errormsg());

        if(!db2_execute($update_stmt, $data))
            throw new Exception("db2_execute() failed! : ". db2_stmt_errormsg());
    }

    public function find_all( ) {
        $conn = DB2Connection::getInstance();

        $select_all_sql = "select * from person";

        $select_all_stmt = db2_prepare($conn, $select_all_sql);
        if (!$select_all_stmt) throw new Exception("Select ALL prepare failed! ". db2_stmt_errormsg());

        if (!db2_execute($select_all_stmt))
            throw new Exception("db2_execute() failed! : ". db2_stmt_errormsg());

        $all_rows = array();
        while ($row = db2_fetch_assoc($select_all_stmt )) {
            $all_rows[] = $row;
        }

        return $all_rows;
    }

    public function find_row( $id ) {
        $conn = DB2Connection::getInstance();

        $select_row_sql = "select * from person where id = ?";

        $select_row_stmt = db2_prepare($conn, $select_row_sql);
        if (!$select_row_stmt) throw new Exception("Select ROW prepare failed! ". db2_stmt_errormsg());

        if(!db2_execute($select_row_stmt, array($id)))
            throw new Exception("db2_execute() failed! : ". db2_stmt_errormsg());

        $row = db2_fetch_assoc($select_row_stmt);

        return $row;
    }

    public function delete_row( $id ) {
        $conn = DB2Connection::getInstance();

        $delete_row_sql = "delete from person where id = ?";

        $delete_row_stmt = db2_prepare($conn, $delete_row_sql);
        if (!$delete_row_stmt) throw new Exception("Delete ROW prepare failed! ". db2_stmt_errormsg());

        if (!db2_execute($delete_row_stmt, array($id)))
            throw new Exception("db2_execute() failed! : ". db2_stmt_errormsg());

    }
}
