<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
   You may use, distribute and modify this code under the
   terms of the BSD license. See file LICENSE.txt in the
   top-most parent folder distributed with this source code.
   If missing, please write to: johnv@div1sys.com.
*/
require_once('../03-singleton/DB2Connection.php');

class Person_DM {

    private $id;
    private $firstName;
    private $lastName;
    private $dateOfBirth;

    public function __construct( )
    {
    }

    /*
     * Static factory method - create a Person_DM object from DB data
     */
    public static function load(array $data) {
        $person = new Person_DM;
        $person->id = $data['ID'];
        $person->setFirstName($data['FIRSTNAME']);
        $person->setLastName($data['LASTNAME']);
        $person->setDateOfBirth($data['DATEOFBIRTH']);
        return $person;
    }
    /*
     * Getters and Setters
     */
    public function getId() { return $this->id; }
    public function getFirstName() { return $this->firstName; }
    public function getLastName() { return $this->lastName; }
    public function getDateOfBirth() { return $this->dateOfBirth; }

    public function setId( $id ) {
        if (!empty($this->id)) {
            throw new Exception("Value of id field is already set and cannot be changed: id='{$this->id}'");
        }
        $this->id = $id;
    }
    public function setFirstName($firstName) { $this->firstName = trim($firstName); }
    public function setLastName($lastName) { $this->lastName = trim($lastName); }
    public function setDateOfBirth($dateOfBirth) {
        $dateVar = strtotime($dateOfBirth);
        $dateYMD = date('Y-m-d', $dateVar);

        if ($dateYMD !== $dateOfBirth) {
            throw new Exception("Date of Birth is not a valid date format: '{$dateOfBirth}'");
        } else {
            $this->dateOfBirth = $dateOfBirth;
        }
    }

    /*
     * DOMAIN LOGIC (i.e. business logic) METHODS
     */

    public function validateData() {
        static $emptyMsg = 'is required for insert or update';

        if ( empty($this->getFirstName() ) )
            throw new Exception("firstName $emptyMsg");

        if ( empty($this->getLastName() ) )
            throw new Exception("lastName $emptyMsg");

        if (  empty($this->getDateOfBirth() ) )
            throw new Exception("dateOfBirth $emptyMsg");

        return true;
    }

    public function getFullName( ) {
        return $this->getFirstName() . ' ' . $this->getLastName();
    }

    public function getDateOfBirthFormatted( ) {
        return date('D M d, Y', strtotime($this->dateOfBirth));
    }

    public function getAge( ) {
        $datetime1 = new DateTime(date('Ymd'));
        $datetime2 = new DateTime($this->dateOfBirth);
        $interval = $datetime2->diff($datetime1);
        return $interval->format('%r%y years, %m months, %d days');
    }

    public function getAgeText( ) {
        $currDate = date('M d, Y');
        return "{$this->getFullName()} was born on {$this->getDateOfBirthFormatted()}, "
        . "and {$this->getFirstName()}'s age as of $currDate is {$this->getAge()}";

    }

    public function __toString() {
        return <<<PERSON_STRING
    First Name: {$this->getFirstName()}
    Last Name: {$this->getLastName()}
    Date of Birth: {$this->getDateOfBirth()}
PERSON_STRING;
    }

}
